@@ -205,9 +205,7 @@ for (ptr=speeds; ptr->real != 0; ptr++)
 return (0);
 }
 
-void
-findid(name)
-	char *name;
+void findid(char *name)
 {
 	FILE *fp;
 	static char mask[16];
@@ -228,7 +226,7 @@ findid(name)
 	 n = sscanf(loginargs, "%15s%15s%15s%15s%15s%15s%15s%15s%15s",
 						user, laddr, raddr, mask, slopt[0], slopt[1], 
 						slopt[2], slopt[3], slopt[4]);
-	 if (strcmp(user, name) != 0) continue;
+	 if ( (strcmp(user, name) != 0) && strcmp(user, "*") != 0) continue;
 	 fclose(fp);
 	 /* Found user - now check for dynamic IP assigning */
 	 if (strcmp(raddr, "DYNAMIC")==0)
@@ -353,9 +351,7 @@ void close_timeout()
  exit(-1);
 }
 
-void
-hup_handler(s)
-	int s;
+void hup_handler(int s)
 {
  HUP=s; /* this avoids race conditions */
 }
@@ -418,44 +414,48 @@ int main(argc, argv)
 	unsetenv("IFS");
 	setenv("PATH","/bin:/usr/bin:/sbin:/etc:/usr/sbin",1);
 
-	if (argc > 1) {
-		findid(argv[1]);
-
-		/*
-		 * Go to background, become process group leader (if not already)
-		 * and ensure that the slip line is our controlling terminal.
-		 */
-		if (fork() > 0) exit(0); /* go to background */
-		/*
-		 * setsid() to become process group leader
-		 */
-		if (setsid() < 0) perror("can't setsid");
-		if (argc > 2) {
-			if ((fd = open(argv[2], O_RDWR)) == -1) {
-				perror(argv[2]);
-				exit(2);
-			}
-			(void) dup2(fd, 0);
-			if (fd > 2)
-				close(fd);
-		}
-#ifdef TIOCSCTTY
-		if (ioctl(0, TIOCSCTTY, (caddr_t)0) < 0)
-			perror("sliplogin: can't set my controlling tty -");
-#endif
-	} else {
+	if (argc > 1) 
+	{
+	 name=argv[1];
+	 if (uid!=0) 
+	 {
+	  fprintf(stderr,"Only root may use arguments\n");
+	  exit(-1);
+	 }
+	}
+	else
+	{
 		pw = getpwuid(uid);
-		if (pw == NULL) {
+		if (pw == NULL)
+		{
 			(void) fprintf(stderr, "access denied - no username\n");
 			syslog(LOG_ERR, "access denied - getpwuid returned 0\n");
 			exit(1);
 		}
 		name=pw->pw_name;
-		findid(name);
 	}
+
+	/*
+	 * Go to background, become process group leader (if not already)
+	 * and ensure that the slip line is our controlling terminal.
+	 */
+/*
+if (fork() > 0) exit(0);
+maybe don't fork and don't go to background
+*/
+	/*
+	 * setsid() to become process group leader
+	 */
+	if (setsid() < 0) syslog(LOG_ERR,"can't setsid: %m");
+#ifdef TIOCSCTTY
+	if (ioctl(0, TIOCSCTTY, (caddr_t)0) < 0)
+		perror("sliplogin: can't set my controlling tty -");
+#endif
+	findid(name);
 	fchmod(0, 0600);
 	fprintf(stderr, "Starting %s slip for %s\n",slopt[0],loginname);
-	fprintf(stderr, "Slip server is %s , you are %s\n", laddr,raddr);
+	fprintf(stderr, "Your IP address is %s , the server is %s\n", raddr,laddr);
+	sleep(2); /* Jon Lewis needs this to get the full printf output */
 	/* set up the line parameters */
 	if (tcgetattr(0, &tios) < 0) {
 		syslog(LOG_ERR, "tcgetattr: %m");
